import { motion } from "framer-motion";
import comicStripImg from "../assets/Comic Strip.png";
import { useQuery } from "@tanstack/react-query";
import type { Skill, About, TimelineItem } from "@shared/schema";

export default function AboutSection() {
  // Fetch about data from the API
  const { data: aboutData, isLoading: isLoadingAbout } = useQuery<About>({
    queryKey: ['/api/about'],
    staleTime: 60 * 1000, // 1 minute
  });

  // Parse timeline data from JSON string or use as is if already an object
  const timelineData: TimelineItem[] = (() => {
    try {
      if (!aboutData?.timelineData) {
        return [
          {
            year: "2020",
            title: "Started Learning",
            description: "Began my journey in web development and AI."
          },
          {
            year: "2021",
            title: "First Projects",
            description: "Completed several small web applications and AI experiments."
          },
          {
            year: "2022",
            title: "Advanced Learning",
            description: "Dived deeper into machine learning and full-stack development."
          },
          {
            year: "2023",
            title: "Professional Work",
            description: "Started working on larger projects and professional applications."
          }
        ];
      }

      let parsedData;

      // If it's already an array, use it directly
      if (Array.isArray(aboutData.timelineData)) {
        parsedData = aboutData.timelineData;
      }
      // If it's a string, try to parse it
      else if (typeof aboutData.timelineData === 'string') {
        parsedData = JSON.parse(aboutData.timelineData);
      }
      // If it's an object but not an array, convert it
      else if (typeof aboutData.timelineData === 'object') {
        parsedData = Object.values(aboutData.timelineData);
      }
      else {
        throw new Error('Invalid timeline data format');
      }

      // Convert any items using the old format (event) to the new format (title + description)
      return parsedData.map((item: { year: string; title?: string; event?: string; description?: string }) => ({
        year: item.year,
        title: item.title || item.event || '',
        description: item.description || item.event || ''
      }));
    } catch (error) {
      console.error('Error parsing timeline data:', error);
      // Return default timeline on error
      return [
        {
          year: "2020",
          title: "Started Learning",
          description: "Began my journey in web development and AI."
        },
        {
          year: "2021",
          title: "First Projects",
          description: "Completed several small web applications and AI experiments."
        },
        {
          year: "2022",
          title: "Advanced Learning",
          description: "Dived deeper into machine learning and full-stack development."
        },
        {
          year: "2023",
          title: "Professional Work",
          description: "Started working on larger projects and professional applications."
        }
      ];
    }
  })();

  // Fetch skills from the API
  const { data: skills = [], isLoading: isLoadingSkills, error } = useQuery<Skill[]>({
    queryKey: ['/api/skills'],
    staleTime: 60 * 1000, // 1 minute
  });

  // Get all published skills in order
  const technologies = skills
    .filter(skill => skill.isPublished)
    .sort((a, b) => a.order - b.order)
    .map(skill => skill.name);

  // Fallback if no skills are found
  const fallbackTechnologies = isLoadingSkills ? ['Loading...'] :
    error ? ['Failed to load technologies'] :
      technologies.length === 0 ? ['HTML/CSS', 'JavaScript', 'React', 'TypeScript', 'Node.js'] : [];

  // Combine API skills with fallback (only if needed)
  const displayTechnologies = technologies.length > 0 ? technologies : fallbackTechnologies;

  const sectionVariants = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: {
        staggerChildren: 0.1,
        delayChildren: 0.1
      }
    }
  };

  const itemVariants = {
    hidden: { y: 20, opacity: 0 },
    visible: {
      y: 0,
      opacity: 1,
      transition: { duration: 0.5 }
    }
  };

  return (
    <section id="about" className="min-h-screen py-24 px-6">
      <div className="container mx-auto max-w-4xl">
        <motion.div
          initial="hidden"
          whileInView="visible"
          viewport={{ once: true, amount: 0.1 }}
          variants={sectionVariants}
        >
          <motion.p
            variants={itemVariants}
            className="font-mono text-fluid-lg space-fluid-xs"
            style={{ color: "white" }}
          >
            {aboutData?.title || "About Me"}
          </motion.p>

          <motion.h2
            variants={itemVariants}
            className="text-fluid-4xl font-bold space-fluid-xl"
            style={{ color: "white" }}
          >
            {aboutData?.subtitle || "My Background & Journey"}
          </motion.h2>

          <div className="grid md:grid-cols-2 gap-12">
            <div>
              <motion.div
                variants={itemVariants}
                className="bg-gradient-to-br from-black/80 to-black/50 backdrop-blur-sm rounded-xl p-6 md:p-8 border border-white/10 shadow-xl mb-8"
              >
                <motion.h3
                  variants={itemVariants}
                  className="text-fluid-2xl font-semibold mb-6 bg-gradient-to-r from-white to-white/90 bg-clip-text text-transparent"
                >
                  Who I Am
                </motion.h3>

                <motion.p
                  variants={itemVariants}
                  className="text-fluid-base mb-4"
                  style={{ color: "rgba(255, 255, 255, 0.9)" }}
                >
                  I am naturally curious and passionate about learning new ideas/concepts. I draw from the accomplishments
                  of others throughout history for inspiration, from the ancient pyramids to modern engineering. Artificial
                  intelligence, data science, and cybersecurity are modern technologies that interest me. I am exploring
                  AI/data-driven financial solutions, such as predictive modeling for stocks and automating and optimizing
                  business operations.
                </motion.p>

                <motion.p
                  variants={itemVariants}
                  className="text-fluid-base"
                  style={{ color: "rgba(255, 255, 255, 0.9)" }}
                >
                  In my free time, you can find me working on a custom solution with 3D printing, making custom furniture,
                  or watching love is blind. Curiosity, creativity, determination, and integrity are some characteristics
                  I value and what I believe to be the foundation of success.
                </motion.p>
              </motion.div>

              <motion.div
                variants={itemVariants}
                className="mb-8 mt-8"
              >
                <img
                  src={aboutData?.comicImagePath || comicStripImg}
                  alt="My Journey Comic Strip"
                  className="w-full h-auto rounded-lg shadow-lg"
                  onError={(e) => {
                    // Set fallback image if the provided path fails to load
                    const target = e.target as HTMLImageElement;
                    target.src = comicStripImg;
                  }}
                />
              </motion.div>
            </div>

            <div>
              <motion.h3
                variants={itemVariants}
                className="text-fluid-2xl font-semibold space-fluid-md"
                style={{ color: "white" }}
              >
                Work History
              </motion.h3>

              <motion.div
                variants={itemVariants}
                className="space-y-4"
              >
                {timelineData.map((item, index) => (
                  <div className="flex" key={index}>
                    <div className="mr-4 flex-shrink-0">
                      <div className="h-3 w-3 rounded-full mt-1" style={{ backgroundColor: "white" }}></div>
                      {index < timelineData.length - 1 && (
                        <div className="h-full w-0.5 bg-muted ml-1.5"></div>
                      )}
                    </div>
                    <div className="pb-5">
                      <div className="flex flex-row items-center gap-2">
                        <p className="text-fluid-base font-semibold whitespace-nowrap" style={{ color: "white" }}>{item.year}</p>
                        <p className="text-fluid-sm text-muted-foreground mt-1" style={{ color: "rgba(255, 255, 255, 0.7)" }}>{item.description}</p>
                      </div>
                    </div>
                  </div>
                ))}
              </motion.div>

              <motion.div
                variants={itemVariants}
                className="mt-12"
              >
                <motion.h3
                  variants={itemVariants}
                  className="text-fluid-2xl font-semibold space-fluid-md"
                  style={{ color: "white" }}
                >
                  Competencies
                </motion.h3>

                <motion.div
                  variants={itemVariants}
                  className="flex flex-wrap gap-2 mt-4"
                >
                  {displayTechnologies.map((tech: string, index: number) => (
                    <span
                      key={index}
                      className="px-3 py-1 bg-primary/20 border border-primary/30 rounded-full text-fluid-sm flex items-center"
                      style={{ color: "white" }}
                    >
                      {tech}
                    </span>
                  ))}
                </motion.div>
              </motion.div>
            </div>
          </div>
        </motion.div>
      </div>
    </section>
  );
}